@@ -623,6 +623,103 @@ ID要强调当下分解的多样性？因为走势本身就是当下形成中的
 莫问为何，接受走势。走势即因，走势亦果。
 
 --摘自《即缠非缠》微博 2022-02-17
+""",
+
+    "71": """
+股票市场，不是一个单纯的理论问题。虽然在理论上，本ID可以向所有人揭示其买卖点的完备性
+，但买卖点不可能自动去买卖，最终的交易是人去完成的，相同的工具，可能在不同的人手下就
+有了完全不同的结果，而市场只看结果，任何人，哭着喊着说自己所用的理论是完备的、最好的
+都没用，是人使理论，而非理论使人，要让这人使理论达到理论一般的完美，最终只能靠自己在
+市场中的修炼了，这就与《论语》有着密切的关系了。修、齐、治、平，同样适用于股票市场的
+交易。
+
+--摘自《2007-01-09 15:03 教你炒股票21：缠中说禅买卖点分析的完备性》
+""",
+
+    "72": """
+站在中线的角度，超短线其实意义并不太大，有能力就玩，没能力就算了。关键是要
+抓住大级别的调整，不参与其中，这才是最关键的。
+
+--摘自《2007-01-23 15:13 教你炒股票25：吻，MACD、背弛、中枢》
+""",
+
+    "73": """
+任何的交易都必须有钱，也就是交易的前提是先有钱，一旦钱是有限期的，那么等于自动设置了一
+个停止交易的时限，这样的交易，是所有失败交易中最常见的一种，以前很多人死在透支上，其实就
+是这种情况。任何交易的钱，最好是无限期的，如果真有什么限期，也是足够长的，这是投资中极为
+关键的一点。一个有限期的钱，唯一可能就是把操作的级别降到足够低，这样才能把这个限期的风险
+尽量控制，但这只是一个没有办法的办法，最好别出现。
+
+--摘自《2007-01-30 15:09 教你炒股票26：市场风险如何回避》
+""",
+
+    "74": """
+走势是怎么出来的？是用钱堆出来的！在这资本的社会里，又有什么比用实在的钱堆出来的更可信？
+除了走势，又有什么是更值得相信的？而那些更值得相信的东西，又有哪样不是建筑在金钱之上的？
+资本市场就是一个金钱的游戏，除了钱，还是钱。只有钱是唯一值得信任的，而钱在市场上运动的轨
+迹，就是走势。这是市场中唯一可以观察与值得观察的东西。
+
+--摘自《2007-01-30 15:09 教你炒股票26：市场风险如何回避》
+""",
+
+    "75": """
+交易的本质就是投入一笔钱，在若干时间后换成另一笔钱出来，其中的凭证就是交易的品种。本质上
+，任何东西都可以是交易品种，所谓股票的价值，不过是引诱你把钱投进来的诱饵。应用本ID理论的
+人，绝对要首先认清楚这一点。对于你投入的钱来说，那些能让你在下一时刻变成更多的钱出来的凭
+证就是有价值的。
+
+--摘自《2007-01-30 15:09 教你炒股票26：市场风险如何回避》
+""",
+
+    "76": """
+市场上，对任何的股票都不值得产生感情，没有任何股票可以给你带来收益，能给你带来收益的是你
+的智慧和能力，那中把钱在另一个时间变成更多钱的智慧和能力。股票永远是孙子，被股票所转的，
+就连孙子都不如了。
+
+--摘自《2007-01-30 15:09 教你炒股票26：市场风险如何回避》
+""",
+
+    "77": """
+市场的唯一风险就是你投入的钱在后面的时刻不能用相应的凭证换成更多的钱。但任何的凭证，本质
+上都是废纸，以0以上的任何价格进行的任何交易都必然包含风险，也就是说，都可能导致投入的钱
+在后面的某一时刻不能换回更多的钱，所以，交易的风险永远存在。
+
+--摘自《2007-01-30 15:09 教你炒股票26：市场风险如何回避》
+""",
+
+    "78": """
+有什么样的可能，使得交易是毫无风险的？唯一的可能，就是你拥有一个负价格的凭证。什么是真正
+的高手、永远不败的高手？就是有本事在相应的时期内把任何的凭证变成负价格的人。对于真正的高
+手来说，交易什么其实根本不重要，只要市场有波动，就可以把任何的凭证在足够长的时间内变成负
+价格。本ID的理论，本质上只探讨一个问题，如何把任何价格的凭证，最终都把其价格在足够长的时
+间内变成负数。
+
+--摘自《2007-01-30 15:09 教你炒股票26：市场风险如何回避》
+""",
+
+    "79": """
+级别的意义，其实只有一个，基本只和买卖量有关，日线级别的买卖量当然比1分钟级别的要多多了。
+
+--摘自《2007-01-30 15:09 教你炒股票26：市场风险如何回避》
+""",
+
+    "80": """
+人类社会，“地”的一种形态，不过是“天人相应”而成，无所谓“天”，无所谓“人”，“天人相应”而成
+这人类社会这“地”的特殊形态。天，“地人相应”而成；人，“天地相应”而成；地，“天人相应”而成。
+成无所成，不过是相续相缠，相应而已。
+
+“天地人”结构最重要之一的关系就是“相应”，就是“和”。就如同音乐中的即兴演奏，这宇宙就在这
+相续相缠中“和”、“相应”，这里没有任何需要“不断重复”去达到聚集的。企图通过“不断重复”去聚
+集点什么玩意、抓住点什么玩意，不过是小人“我”之私心相应之妄想。
+
+--摘自《2007-09-09 18:34 《论语》详解：给所有曲解孔子的人（69）》
+""",
+
+    "81": """
+世界“不知”，君子“周”其“不知”而“不相”之，转“不知”之世界为“不愠”之世界，而君子，本无能转
+所转。就如同阳光普照，无所谓照物，而物得阳光而自彰，阳光本无能彰所彰。
+
+--摘自《2007-08-28 21:57 《论语》详解：给所有曲解孔子的人（68）》
 """,
 
 }
